@@ -7,7 +7,7 @@ from json import JSONDecodeError
 
 import requests
 
-__version__ = "0.5.3"
+__version__ = "0.5.4"
 __author__ = "Kartik Talwar"
 __email__ = "hi@kartikt.com"
 __url__ = "https://github.com/KartikTalwar/duolingo"
@@ -104,7 +104,7 @@ class Duolingo(object):
         request = self._make_req(login_url, data)
         attempt = request.json()
 
-        if attempt.get('response') == 'OK':
+        if "failure" not in attempt:
             self.jwt = request.headers['jwt']
             self._save_session_to_file()
             return True
